@@ -6,6 +6,7 @@ from builtins import str
 import argparse
 import os
 import subprocess
+import traceback
 import urllib.request, urllib.error, urllib.parse
 from . import utils
 import sys
@@ -242,7 +243,7 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
         get_collector_files(collector_name, modules_path, s3_base_collectors_link)
 
     except Exception as e:
-        print ("Could not get collector " + collector_name + " Exception : " + str(e))
+        print ("Failed to load Module: %s. %s" % (e, traceback.format_exc()))
 
 
 def get_worker_files(modules_path, s3_base_workers_link, worker_name):
