@@ -210,7 +210,7 @@ def parse_yml(yml, log=logging.getLogger('spotinst-agent')):
     # Initialize Config
     with open(yml) as f:
         try:
-            return yaml.load(f, yaml.FullLoader)
+            return yaml.load(f)
         except Exception as e:
             log.error("Can't parse yml file {}. Exception {}".format(yml, e))
             raise e
